grille_pain/lustre/toast
grille_pain/lustre/toast defines the different effects to use to display
toasts with lustre.
Types
Options type allow to modify timeout or level at the notification level
directly. This is used to create custom toasts and override defaults.
If you don’t need custom toasts, you should head up to default functions
(toast, info, success, error and warning).
It follows the Builder pattern.
import grille_pain/toast
import grille_pain/toast/level
fn custom_toast() {
toast.options()
|> toast.timeout(millisecond1s: 30_000)
|> toast.level(level.Warning)
|> toast.custom("Oops")
}
pub type Options =
toast.Options